pub struct Options {
pub quiet: bool,
pub expressions: Vec<String>,
pub script_files: Vec<PathBuf>,
pub in_place: Option<String>,
pub extended_regexp: bool,
pub separate: bool,
pub null_data: bool,
pub args: Vec<String>,
}Fields
quiet: boolSuppress automatic printing of pattern space
expressions: Vec<String>Add the script to the commands to be executed
script_files: Vec<PathBuf>Add the contents of script-file to the commands to be executed
in_place: Option<String>Edit files in place (makes backup if SUFFIX supplied). Use –in-place=SUFFIX or -iSUFFIX (no space) for backups.
extended_regexp: boolUse extended regular expressions (accepted for compatibility; always enabled)
separate: boolConsider files as separate rather than as a single continuous stream
null_data: boolSeparate lines by NUL characters
args: Vec<String>[SCRIPT] [INPUT-FILE…]
Implementations